@@ -5,6 +5,7 @@ from sqlalchemy import Column, String, Integer, Table, ForeignKey
 from sqlalchemy.orm import relationship
 
 from poindexter.models import Base
+from poindexter.models.CSECX import CSECX
 from poindexter.models.Domain import Domain
 
 
@@ -15,15 +16,22 @@ CSE_Domain_Table = Table(
   Column('domain_id', ForeignKey('domains.id'))
 )
 
+CSE_CX_Table = Table(
+  'cse_cx_association',
+  Base.metadata,
+  Column('cse_id', ForeignKey('cses.id')),
+  Column('cx_id', ForeignKey('cxes.id'))
+)
+
 
 class CSECreate(BaseModel):
   name: str
-  cx: str
   description: str
 
 
 class CSE(CSECreate):
   id: int
+  cxes: List[CSECX] = []
   domains: List[Domain] = []
   class Config:
     orm_mode = True
@@ -33,6 +41,6 @@ class CSEModel(Base):
   __tablename__ = 'cses'
   id = Column(Integer, primary_key=True, index=True)
   name = Column(String)
-  cx = Column(String)
   description = Column(String)
+  cxes = relationship("CXModel", secondary=CSE_CX_Table)
   domains = relationship("DomainModel", secondary=CSE_Domain_Table)
